for что in ["элемент", "множество"]:
    for где in ["элемент", "множество"]:
        for регистр in ["важен", "не важен"]:
            for результат in ["содержит", "не содержит"]:
                print(f"{что} - {где}, регистр {регистр}, результат - {результат}")


видео = ".mp4"
картинка = ".jpg"
музыка = ".mp3"
ворд = ".docx"
текст = ".txt"
книга = ".fb2"
эксель = ".xlsx"

список_видео = ["фильм.mp4", "кино.mp4", "песня.MP3"]
список_картинок = ["котики.jpg", "море.jpg", "каникулы.mp4"]
список_музыки = ["мелодия.mp3", "трек.mp3", "обложка.JPG"]
список_документов = ["доклад.docx", "список дел.txt", "книга.fb2", "таблица.xlsx"]

варианты = [
    ["элемент-элемент, регистр важен, результат - не содержит", ".jpg", "обложка.JPG", True, False],
    ["элемент-элемент, регистр важен, результат - содержит", ".jpg", "котики.jpg", True, True],
    ["элемент-элемент, регистр не важен, результат - не содержит", ".jpg", "песня.MP3", False, False],
    ["элемент-элемент, регистр не важен, результат - содержит", ".jpg", "обложка.JPG", False, True],
    ["элемент-множество, регистр важен, результат - не содержит", ".mp3", список_видео, True, False],
    ["элемент-множество, регистр важен, результат - содержит", ".jpg", список_картинок, True, True],
    ["элемент-множество, регистр не важен, результат - не содержит", ".txt", список_видео, False, False],
    ["элемент-множество, регистр не важен, результат - содержит", ".mp3", список_видео, False, True],
    ["множество-элемент, регистр важен, результат - не содержит", [".jpg", ".mp3"], "песня.MP3", True, False],
    ["множество-элемент, регистр важен, результат - содержит", [".txt", ".mp3"], "список дел.txt", True, True],
    ["множество-элемент, регистр не важен, результат - не содержит", [".xlsx", ".fb2"], "трек.mp3", False, False],
    ["множество-элемент, регистр не важен, результат - содержит", [".jpg", ".mp3"], "песня.MP3", False, True],
    ["множество-множество, регистр важен, результат - не содержит", [".jpg", ".mp3"], список_видео, True, False],
    ["множество-множество, регистр важен, результат - содержит", [".mp4", ".jpg"], список_картинок, True, True],
    ["множество-множество, регистр не важен, результат - не содержит", [".docx", ".xlsx"], список_видео, False, False],
    ["множество-множество, регистр не важен, результат - содержит", [".mp3", ".docx"], список_видео, False, True],
]


# принципы праграмирования TDD  Test Driven Development
# переводиться как "разработка" основанная на тестированиях
# данный принцып претпологает что сначала создаются тесты для нужной функции которые будут проверять все возможные варианты ввода и вывода и только потом пишется сама функция
# При каждом обновлении функции необходимо запустить все тесты и удостовериться что все они пройдены без ошибок 

# тесты всегда должны писаться "явным" образом - все входные данные и ожидаемые результаты работы должны быть записаны "от руки" - они не должны вычислятся самим тестом

def максимальное_число(список):
    if type(список) != list and type(список) != tuple:
        raise TypeError(F"Эта функция может принять только список или кортеж. По факту был передан {type(список)}")

    # список = [5,9,2,3,15]

    наибольшее = список[0]
    for i in range(len(список)):
        элемент = список[i]
        if элемент > наибольшее:
            наибольшее = элемент
    return наибольшее

def максимальное_число_через_сортировку(список):
    список.sort()
    return список[-1]


def тест():

    
    название_теста = "список чисел"
    данные = [5,9,2,3,15]
    ожидаемый_ответ = 15
    результат = максимальное_число(данные)
    if результат == ожидаемый_ответ:
        print(f"Тест '{название_теста}' пройден")
    else:
        print(f"Тест '{название_теста}' не пройден")
        print(f"Ожидался ответ {ожидаемый_ответ}")
        print(f"Полученный ответ {результат}")



    название_теста = "список чисел с отрицательными"
    данные = [2,3,6,12,33,-12,34,-4]
    ожидаемый_ответ = 34
    результат = максимальное_число_через_сортировку(данные)
    if результат == ожидаемый_ответ:
        print(f"Тест '{название_теста}' пройден")
    else:
        print(f"Тест '{название_теста}' не пройден")
        print(f"Ожидался ответ {ожидаемый_ответ}")
        print(f"Полученный ответ {результат}")



    название_теста = "передан не список"
    данные = "какой то текст"
    ожидаемый_ответ = "ошибка"
    try:
        результат = максимальное_число(данные)
    except:
        результат = "ошибка"
    if результат == ожидаемый_ответ:
        print(f"Тест '{название_теста}' пройден")
    else:
        print(f"Тест '{название_теста}' не пройден")
        print(f"Ожидался ответ {ожидаемый_ответ}")
        print(f"Полученный ответ {результат}")

тест()


from setuptools import setup

setup(
    name="Worzis_tools", # имя модуля, которое будет использоваться при установке в будущем
    version="1.211", # версия модуля при каждом обновлении (новой отправке надо версию увеличивать)
    description="", # описание (можно не использовать)
    packages=["Worzis_tools"], # список с названием папок которые нужно залить
    author_email="dag201011@gmail.com", # почта автора модуля
    zip_safe=False, # пароль
    install_requires=['colorama'], # список названий модулей которые нужны для корректной работы вашего модуля
) 